![banner](/docs/source/_static/banner.svg)

[![PyPI Version](https://img.shields.io/pypi/v/dpeeg)](https://pypi.org/project/dpeeg/)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.13989420.svg)](https://doi.org/10.5281/zenodo.13989420)
[![Documentation Status](https://readthedocs.org/projects/dpeeg/badge/?version=stable)](https://dpeeg.readthedocs.io/stable/?badge=stable)
[![PyPI - License](https://img.shields.io/pypi/l/dpeeg)](https://opensource.org/licenses/MIT)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

**dpeeg** provides a complete workflow for deep learning decoding EEG tasks, 
including basic datasets (datasets can be easily customized), basic network 
models, model training, rich experiments, and detailed experimental result 
storage.

# Installation

1. Create a new virtual environment named "dpeeg" with 
[Python](https://www.python.org/) >= 3.10 using Anaconda3 and activate it：
```Shell
conda create --name dpeeg python
conda activate dpeeg
```

2. dpeeg depends on [Pytorch](https://pytorch.org/). Please refer to the 
corresponding official website for installation.

3. Complete the installation via `pip`:
```Shell
pip install dpeeg
``` 

# How to cite

If you would like to cite dpeeg you can do so using our 
[Zenodo deposit](https://zenodo.org/records/13989420).